==> jc-1.4.0.tar.gz: polyglot/visit/AmbiguityRemover.h <==
// public class polyglot.visit.AmbiguityRemover

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 67d28117807b75a9 polyglot_visit_AmbiguityRemover
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_AmbiguityRemover_H_
#define _JC_polyglot_visit_AmbiguityRemover_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_AmbiguityRemover$sub_refs	_jc_polyglot_visit_AmbiguityRemover$sub_refs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$sub_nonrefs	_jc_polyglot_visit_AmbiguityRemover$sub_nonrefs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$refs	_jc_polyglot_visit_AmbiguityRemover$refs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$nonrefs	_jc_polyglot_visit_AmbiguityRemover$nonrefs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$object	_jc_polyglot_visit_AmbiguityRemover$object;

typedef struct _jc_polyglot_visit_AmbiguityRemover$fields_struct	_jc_polyglot_visit_AmbiguityRemover$fields_struct;
typedef const struct _jc_polyglot_visit_AmbiguityRemover$vmethods	_jc_polyglot_visit_AmbiguityRemover$vmethods;
typedef const struct _jc_polyglot_visit_AmbiguityRemover$vtable	_jc_polyglot_visit_AmbiguityRemover$vtable;
typedef const struct _jc_polyglot_visit_AmbiguityRemover$vtype	_jc_polyglot_visit_AmbiguityRemover$vtype;

// Class fields structure
struct _jc_polyglot_visit_AmbiguityRemover$fields_struct {
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*ALL;
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*FIELDS;
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*SIGNATURES;
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*SUPER;
};
extern _jc_polyglot_visit_AmbiguityRemover$fields_struct _jc_polyglot_visit_AmbiguityRemover$class_fields;

// Constructors
extern void _jc_polyglot_visit_AmbiguityRemover$method$_init$39afc4263d3ac8a1(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object *);

// Virtual methods
extern void _jc_polyglot_visit_AmbiguityRemover$method$addSuperDependencies$cb9538bbf76f04a0(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *);
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_AmbiguityRemover$method$enterCall$91bb061343e6f272(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *);
extern struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object *_jc_polyglot_visit_AmbiguityRemover$method$kind$0de88fd281112f42(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *);
extern struct _jc_object *_jc_polyglot_visit_AmbiguityRemover$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$addSuperDependencies$cb9538bbf76f04a0;
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$enterCall$91bb061343e6f272;
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$kind$0de88fd281112f42;
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$leaveCall$9236e830bcef4b36;

// Static methods
extern void _jc_polyglot_visit_AmbiguityRemover$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_visit_AmbiguityRemover$vmethods {
	void	(*addSuperDependencies$cb9538bbf76f04a0)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *);
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$91bb061343e6f272)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *);
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*(*kind$0de88fd281112f42)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *);
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_AmbiguityRemover$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_AmbiguityRemover$vmethods	polyglot_visit_AmbiguityRemover;
};

// Vtype
struct _jc_polyglot_visit_AmbiguityRemover$vtype {
	_jc_type			type;
	_jc_polyglot_visit_AmbiguityRemover$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_AmbiguityRemover$sub_refs {
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*kind;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_AmbiguityRemover$refs {
    _jc_polyglot_visit_AmbiguityRemover$sub_refs	polyglot_visit_AmbiguityRemover;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_AmbiguityRemover$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_AmbiguityRemover$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_AmbiguityRemover$sub_nonrefs	polyglot_visit_AmbiguityRemover;
};

// Object instance structure
struct _jc_polyglot_visit_AmbiguityRemover$object {
	_jc_polyglot_visit_AmbiguityRemover$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_AmbiguityRemover$vtype	*vtype;
	_jc_polyglot_visit_AmbiguityRemover$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_AmbiguityRemover$vtype _jc_polyglot_visit_AmbiguityRemover$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_AmbiguityRemover, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_AmbiguityRemover$class_object;

#endif	/* _JC_polyglot_visit_AmbiguityRemover_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/AmbiguityRemover.h <==
// public class polyglot.visit.AmbiguityRemover

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 67d28117807b75a9 polyglot_visit_AmbiguityRemover
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_AmbiguityRemover_H_
#define _JC_polyglot_visit_AmbiguityRemover_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_AmbiguityRemover$sub_refs	_jc_polyglot_visit_AmbiguityRemover$sub_refs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$sub_nonrefs	_jc_polyglot_visit_AmbiguityRemover$sub_nonrefs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$refs	_jc_polyglot_visit_AmbiguityRemover$refs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$nonrefs	_jc_polyglot_visit_AmbiguityRemover$nonrefs;
typedef struct _jc_polyglot_visit_AmbiguityRemover$object	_jc_polyglot_visit_AmbiguityRemover$object;

typedef struct _jc_polyglot_visit_AmbiguityRemover$fields_struct	_jc_polyglot_visit_AmbiguityRemover$fields_struct;
typedef const struct _jc_polyglot_visit_AmbiguityRemover$vmethods	_jc_polyglot_visit_AmbiguityRemover$vmethods;
typedef const struct _jc_polyglot_visit_AmbiguityRemover$vtable	_jc_polyglot_visit_AmbiguityRemover$vtable;
typedef const struct _jc_polyglot_visit_AmbiguityRemover$vtype	_jc_polyglot_visit_AmbiguityRemover$vtype;

// Class fields structure
struct _jc_polyglot_visit_AmbiguityRemover$fields_struct {
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*ALL;
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*FIELDS;
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*SIGNATURES;
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*SUPER;
};
extern _jc_polyglot_visit_AmbiguityRemover$fields_struct _jc_polyglot_visit_AmbiguityRemover$class_fields;

// Constructors
extern void _jc_polyglot_visit_AmbiguityRemover$method$_init$39afc4263d3ac8a1(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_visit_AmbiguityRemover$method$addSuperDependencies$cb9538bbf76f04a0(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_AmbiguityRemover$method$enterCall$91bb061343e6f272(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object *_jc_polyglot_visit_AmbiguityRemover$method$kind$0de88fd281112f42(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_AmbiguityRemover$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$addSuperDependencies$cb9538bbf76f04a0;
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$enterCall$91bb061343e6f272;
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$kind$0de88fd281112f42;
extern _jc_method _jc_polyglot_visit_AmbiguityRemover$method_info$leaveCall$9236e830bcef4b36;

// Static methods
extern void _jc_polyglot_visit_AmbiguityRemover$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_AmbiguityRemover$vmethods {
	void	(*addSuperDependencies$cb9538bbf76f04a0)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$91bb061343e6f272)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*(*kind$0de88fd281112f42)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_polyglot_visit_AmbiguityRemover$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_AmbiguityRemover$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_AmbiguityRemover$vmethods	polyglot_visit_AmbiguityRemover;
};

// Vtype
struct _jc_polyglot_visit_AmbiguityRemover$vtype {
	_jc_type			type;
	_jc_polyglot_visit_AmbiguityRemover$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_AmbiguityRemover$sub_refs {
	struct _jc_polyglot_visit_AmbiguityRemover__24Kind$object	*kind;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_AmbiguityRemover$refs {
    _jc_polyglot_visit_AmbiguityRemover$sub_refs	polyglot_visit_AmbiguityRemover;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_AmbiguityRemover$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_AmbiguityRemover$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_AmbiguityRemover$sub_nonrefs	polyglot_visit_AmbiguityRemover;
};

// Object instance structure
struct _jc_polyglot_visit_AmbiguityRemover$object {
	_jc_polyglot_visit_AmbiguityRemover$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_AmbiguityRemover$vtype	*vtype;
	_jc_polyglot_visit_AmbiguityRemover$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_AmbiguityRemover$vtype _jc_polyglot_visit_AmbiguityRemover$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_AmbiguityRemover, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_AmbiguityRemover$class_object;

#endif	/* _JC_polyglot_visit_AmbiguityRemover_H_ */
